=========================
Oscar 0.7.3 release notes
=========================

This is Oscar 0.7.3, a tiny release to relax the dependency restrictions for
South and django-compressor: 

* South 1.0 can now be used with Oscar 0.7.3. Previously it was capped at 0.9.
* django-compressor 1.4 can now be used with Oscar 0.7.3 when running Python 2.7
  (Previously 1.3 was specified for Python 2.7, while 1.4a was specified for
  Python 3).
